drop procedure if exists dud_import_user;
drop procedure if exists dud_import_topics;

delimiter $$

create procedure dud_import_user()
begin
	declare done boolean default FALSE;
	declare name varchar(128);
	declare regdate datetime;
	declare cnt int default 0;	
	declare cur1 CURSOR FOR select author, datetime from ideas;
	declare cur2 CURSOR FOR select author, datetime from comments;
	declare continue handler for sqlstate '02000' SET done=TRUE;
	
	open cur1;
	read_loop: loop
		fetch cur1 into name, regdate;
    		if done then
      			leave read_loop;
    		end if;
		select count(*) into cnt from phpbb3.phpbb_users where username=name or username_clean=name;
		if cnt = 0 then
			insert into phpbb3.phpbb_users(user_regdate, username, username_clean) values(unix_timestamp(regdate), name, name);
		end if;
	end loop;
	close cur1;

	set done=FALSE;
	open cur2;
	read_loop: loop
		fetch cur2 into name, regdate;
    		if done then
      			leave read_loop;
    		end if;		
		select count(*) into cnt from phpbb3.phpbb_users where username=name or username_clean=name;
		if cnt = 0 then
			insert into phpbb3.phpbb_users(user_regdate, username, username_clean) values(unix_timestamp(regdate), name, name);
		end if;
	end loop;
	close cur2;
end$$

create procedure dud_import_topics(in forum_id INT)
begin
	declare done boolean default FALSE;
	declare author_i varchar(128);
	declare ididea_i int;
	declare date_i datetime;
	declare title_i varchar(256);
	declare text_i text;
	declare uid int;
	declare last_topic_id int;
	declare post_count int;
	declare last_poster_id mediumint(8);
	declare last_poster_name varchar(128);	
	declare last_post_time int;
		
	declare cur1 CURSOR FOR select ididea, author, headline, idea, datetime from ideas order by datetime;	
	declare continue handler for sqlstate '02000' SET done=TRUE;

	open cur1;

	read_loop: loop
		fetch cur1 into ididea_i, author_i, title_i, text_i, date_i;
		if done then
			leave read_loop;
		end if;
		select user_id into uid from phpbb3.phpbb_users where username=author_i;
		if isnull(uid) then
			set uid=1;
		end if;
		insert into phpbb3.phpbb_topics(`forum_id`, topic_title, topic_poster, topic_time, topic_first_poster_name) values(forum_id, title_i, uid, unix_timestamp(date_i), author_i);
		select last_insert_id() into last_topic_id;
		insert into phpbb3.phpbb_posts(topic_id, poster_id, post_username, post_time, post_subject, post_text) values(last_topic_id, uid, author_i, unix_timestamp(date_i), title_i, text_i);
		
		insert into phpbb3.phpbb_posts(topic_id, poster_id, post_username, post_time, post_subject, post_text)
		select last_topic_id, ifnull(user_id, 1), comments.author, unix_timestamp(datetime), title_i, comment from comments left outer join phpbb3.phpbb_users on username=author where ididea=ididea_i;
				
		select count(*) into post_count from phpbb3.phpbb_posts where topic_id=last_topic_id;
		select poster_id, post_username, post_time into last_poster_id, last_poster_name, last_post_time from phpbb3.phpbb_posts where topic_id=last_topic_id order by post_time desc limit 1; 	
		update phpbb3.phpbb_topics set topic_replies=post_count, topic_replies_real=post_count, topic_last_poster_id=last_poster_id, topic_last_poster_name=last_poster_name, topic_last_post_time=last_post_time where topic_id=last_topic_id;

		set done=FALSE;		
	end loop;

	close cur1;
end$$